
"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.container.contained import Contained
from zope.interface import Interface, implementer

from onf_website import _
from onf_website.shared.planning import FakePlanning, IPlanningManager
from onf_website.shared.planning import PlanningLinkPortletRenderer
from onf_website.shared.planning.interfaces import IPlanningLinkPortletSettings
from onf_website.shared.planning.skin.interfaces import IPlanningLinkPortletBaseRendererSettings, \
    IPlanningLinkPortletTexturedRendererSettings
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_portal.interfaces import IPortalPage, IPortalTemplate
from pyams_portal.page import PortalPage
from pyams_skin.interfaces.metas import IHTMLContentMetas
from pyams_skin.layer import IPyAMSLayer, IPyAMSUserLayer
from pyams_skin.metas import HTMLTagMeta
from pyams_template.template import template_config
from pyams_utils.adapter import ContextAdapter, ContextRequestAdapter, ContextRequestViewAdapter, \
    adapter_config
from pyams_utils.factory import factory_config
from pyams_utils.interfaces.url import ICanonicalURL
from pyams_utils.registry import query_utility
from pyams_utils.unicode import translate_string
from pyams_utils.url import absolute_url


@adapter_config(context=FakePlanning, provides=IPortalPage)
class FakePlanningPortalPage(ContextAdapter, PortalPage):
    """Fake planning portal page"""

    can_inherit = False

    @property
    def template(self):
        manager = query_utility(IPlanningManager)
        if manager is None:
            return None
        planning, info = self.context.get_planning_refs().first()
        if (planning is None) or (planning.categorie_proprietaire is None):
            return None
        template = manager.templates.get(planning.categorie_proprietaire)
        if template is not None:
            return query_utility(IPortalTemplate, name=template)
        return IPortalPage(manager).template


@adapter_config(name='title',
                context=(FakePlanning, IPyAMSUserLayer, Interface),
                provides=IHTMLContentMetas)
class SharedContentTitleMetasAdapter(ContextRequestViewAdapter):
    """Title metas adapter"""

    order = 1

    def get_metas(self):
        """Get HTML metas headers"""
        yield HTMLTagMeta('title', self.context.title)


@adapter_config(context=(FakePlanning, IPyAMSUserLayer),
                provides=ICanonicalURL)
class FakePlanningCanonicalUrl(ContextRequestAdapter):
    """Fake planning canonical URL adapter"""

    def get_url(self, view_name=None, query=None):
        context = None
        manager = query_utility(IPlanningManager)
        if manager is not None:
            context = manager.get_default_source()
        if context is None:
            return '{}/+a/{}::{}.html'.format(absolute_url(self.request.root, self.request),
                                              ''.join(self.context.planning_ids).lower(),
                                              translate_string(self.context.title, spaces='-'))
        return '{}/++amgt++{}::{}.html'.format(absolute_url(context, self.request),
                                               ''.join(self.context.planning_ids).lower(),
                                               translate_string(self.context.title, spaces='-'))



@implementer(IPlanningLinkPortletBaseRendererSettings)
class PlanningLinkPortletBaseRendererSettings(Persistent, Contained):
    """Planning Link portlet base renderer settings"""

#
# Textured view renderer
#

@factory_config(provided=IPlanningLinkPortletTexturedRendererSettings)
class PlanningLinkPortletTexturedRendererSettings(PlanningLinkPortletBaseRendererSettings):
    """Onf planning link textured renderer settings"""


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, IPlanningLinkPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/textured.pt', layer=IPyAMSUserLayer)
class PlanningLinkPortletTexturedRenderer(PlanningLinkPortletRenderer):
    """Planning Link portlet textured renderer"""

    label = _("ONF: textured card")
    weight = 21

    settings_interface = IPlanningLinkPortletTexturedRendererSettings

